Documentation
¶
Index ¶
- Constants
- Variables
- func Factory(ctx context.Context, config rest.Config) (context.Context, controller.Starter, error)
- func Kind(kind string) schema.GroupKind
- func NewConfigMap(namespace, name string, obj v1.ConfigMap) *v1.ConfigMap
- func NewEndpoints(namespace, name string, obj v1.Endpoints) *v1.Endpoints
- func NewNode(namespace, name string, obj v1.Node) *v1.Node
- func NewPod(namespace, name string, obj v1.Pod) *v1.Pod
- func NewService(namespace, name string, obj v1.Service) *v1.Service
- func NewServiceAccount(namespace, name string, obj v1.ServiceAccount) *v1.ServiceAccount
- func Resource(resource string) schema.GroupResource
- type Client
- func (c *Client) ConfigMaps(namespace string) ConfigMapInterface
- func (c *Client) Endpoints(namespace string) EndpointsInterface
- func (c *Client) Nodes(namespace string) NodeInterface
- func (c *Client) Pods(namespace string) PodInterface
- func (c *Client) RESTClient() rest.Interface
- func (c *Client) ServiceAccounts(namespace string) ServiceAccountInterface
- func (c *Client) Services(namespace string) ServiceInterface
- func (c *Client) Start(ctx context.Context, threadiness int) error
- func (c *Client) Sync(ctx context.Context) error
- type Clients
- type ConfigMapChangeHandlerFunc
- type ConfigMapClient
- type ConfigMapClientCache
- type ConfigMapController
- type ConfigMapHandlerFunc
- type ConfigMapIndexer
- type ConfigMapInterface
- type ConfigMapLifecycle
- type ConfigMapList
- type ConfigMapLister
- type ConfigMapsGetter
- type EndpointsChangeHandlerFunc
- type EndpointsClient
- type EndpointsClientCache
- type EndpointsController
- type EndpointsGetter
- type EndpointsHandlerFunc
- type EndpointsIndexer
- type EndpointsInterface
- type EndpointsLifecycle
- type EndpointsList
- type EndpointsLister
- type Interface
- type NodeChangeHandlerFunc
- type NodeClient
- type NodeClientCache
- type NodeController
- type NodeHandlerFunc
- type NodeIndexer
- type NodeInterface
- type NodeLifecycle
- type NodeList
- type NodeLister
- type NodesGetter
- type PodChangeHandlerFunc
- type PodClient
- type PodClientCache
- type PodController
- type PodHandlerFunc
- type PodIndexer
- type PodInterface
- type PodLifecycle
- type PodList
- type PodLister
- type PodsGetter
- type ServiceAccountChangeHandlerFunc
- type ServiceAccountClient
- type ServiceAccountClientCache
- type ServiceAccountController
- type ServiceAccountHandlerFunc
- type ServiceAccountIndexer
- type ServiceAccountInterface
- type ServiceAccountLifecycle
- type ServiceAccountList
- type ServiceAccountLister
- type ServiceAccountsGetter
- type ServiceChangeHandlerFunc
- type ServiceClient
- type ServiceClientCache
- type ServiceController
- type ServiceHandlerFunc
- type ServiceIndexer
- type ServiceInterface
- type ServiceLifecycle
- type ServiceList
- type ServiceLister
- type ServicesGetter
Constants ¶
const ( GroupName = "" Version = "v1" )
Variables ¶
var ( ConfigMapGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "ConfigMap", } ConfigMapResource = metav1.APIResource{ Name: "configmaps", SingularName: "configmap", Namespaced: true, Kind: ConfigMapGroupVersionKind.Kind, } )
var ( EndpointsGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "Endpoints", } EndpointsResource = metav1.APIResource{ Name: "endpoints", SingularName: "endpoints", Namespaced: true, Kind: EndpointsGroupVersionKind.Kind, } )
var ( NodeGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "Node", } NodeResource = metav1.APIResource{ Name: "nodes", SingularName: "node", Namespaced: false, Kind: NodeGroupVersionKind.Kind, } )
var ( PodGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "Pod", } PodResource = metav1.APIResource{ Name: "pods", SingularName: "pod", Namespaced: true, Kind: PodGroupVersionKind.Kind, } )
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var ( ServiceAccountGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "ServiceAccount", } ServiceAccountResource = metav1.APIResource{ Name: "serviceaccounts", SingularName: "serviceaccount", Namespaced: true, Kind: ServiceAccountGroupVersionKind.Kind, } )
var ( ServiceGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "Service", } ServiceResource = metav1.APIResource{ Name: "services", SingularName: "service", Namespaced: true, Kind: ServiceGroupVersionKind.Kind, } )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: Version}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func NewServiceAccount ¶
func NewServiceAccount(namespace, name string, obj v1.ServiceAccount) *v1.ServiceAccount
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type Client ¶
func (*Client) ConfigMaps ¶
func (c *Client) ConfigMaps(namespace string) ConfigMapInterface
func (*Client) Endpoints ¶
func (c *Client) Endpoints(namespace string) EndpointsInterface
func (*Client) Nodes ¶
func (c *Client) Nodes(namespace string) NodeInterface
func (*Client) Pods ¶
func (c *Client) Pods(namespace string) PodInterface
func (*Client) RESTClient ¶
func (*Client) ServiceAccounts ¶
func (c *Client) ServiceAccounts(namespace string) ServiceAccountInterface
func (*Client) Services ¶
func (c *Client) Services(namespace string) ServiceInterface
type Clients ¶
type Clients struct {
Interface Interface
Node NodeClient
ServiceAccount ServiceAccountClient
Endpoints EndpointsClient
Service ServiceClient
Pod PodClient
ConfigMap ConfigMapClient
}
func ClientsFrom ¶
func NewClientsFromInterface ¶
type ConfigMapClient ¶
type ConfigMapClient interface {
Create(*v1.ConfigMap) (*v1.ConfigMap, error)
Get(namespace, name string, opts metav1.GetOptions) (*v1.ConfigMap, error)
Update(*v1.ConfigMap) (*v1.ConfigMap, error)
Delete(namespace, name string, options *metav1.DeleteOptions) error
List(namespace string, opts metav1.ListOptions) (*ConfigMapList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Cache() ConfigMapClientCache
OnCreate(ctx context.Context, name string, sync ConfigMapChangeHandlerFunc)
OnChange(ctx context.Context, name string, sync ConfigMapChangeHandlerFunc)
OnRemove(ctx context.Context, name string, sync ConfigMapChangeHandlerFunc)
Enqueue(namespace, name string)
Generic() controller.GenericController
ObjectClient() *objectclient.ObjectClient
Interface() ConfigMapInterface
}
type ConfigMapClientCache ¶
type ConfigMapController ¶
type ConfigMapController interface {
Generic() controller.GenericController
Informer() cache.SharedIndexInformer
Lister() ConfigMapLister
AddHandler(ctx context.Context, name string, handler ConfigMapHandlerFunc)
AddClusterScopedHandler(ctx context.Context, name, clusterName string, handler ConfigMapHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type ConfigMapHandlerFunc ¶
func NewConfigMapLifecycleAdapter ¶
func NewConfigMapLifecycleAdapter(name string, clusterScoped bool, client ConfigMapInterface, l ConfigMapLifecycle) ConfigMapHandlerFunc
type ConfigMapInterface ¶
type ConfigMapInterface interface {
ObjectClient() *objectclient.ObjectClient
Create(*v1.ConfigMap) (*v1.ConfigMap, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.ConfigMap, error)
Get(name string, opts metav1.GetOptions) (*v1.ConfigMap, error)
Update(*v1.ConfigMap) (*v1.ConfigMap, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*ConfigMapList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() ConfigMapController
AddHandler(ctx context.Context, name string, sync ConfigMapHandlerFunc)
AddLifecycle(ctx context.Context, name string, lifecycle ConfigMapLifecycle)
AddClusterScopedHandler(ctx context.Context, name, clusterName string, sync ConfigMapHandlerFunc)
AddClusterScopedLifecycle(ctx context.Context, name, clusterName string, lifecycle ConfigMapLifecycle)
}
type ConfigMapLifecycle ¶
type ConfigMapList ¶
type ConfigMapList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.ConfigMap
}
func (*ConfigMapList) DeepCopy ¶
func (in *ConfigMapList) DeepCopy() *ConfigMapList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ConfigMapList.
func (*ConfigMapList) DeepCopyInto ¶
func (in *ConfigMapList) DeepCopyInto(out *ConfigMapList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ConfigMapList) DeepCopyObject ¶
func (in *ConfigMapList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ConfigMapLister ¶
type ConfigMapsGetter ¶
type ConfigMapsGetter interface {
ConfigMaps(namespace string) ConfigMapInterface
}
type EndpointsClient ¶
type EndpointsClient interface {
Create(*v1.Endpoints) (*v1.Endpoints, error)
Get(namespace, name string, opts metav1.GetOptions) (*v1.Endpoints, error)
Update(*v1.Endpoints) (*v1.Endpoints, error)
Delete(namespace, name string, options *metav1.DeleteOptions) error
List(namespace string, opts metav1.ListOptions) (*EndpointsList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Cache() EndpointsClientCache
OnCreate(ctx context.Context, name string, sync EndpointsChangeHandlerFunc)
OnChange(ctx context.Context, name string, sync EndpointsChangeHandlerFunc)
OnRemove(ctx context.Context, name string, sync EndpointsChangeHandlerFunc)
Enqueue(namespace, name string)
Generic() controller.GenericController
ObjectClient() *objectclient.ObjectClient
Interface() EndpointsInterface
}
type EndpointsClientCache ¶
type EndpointsController ¶
type EndpointsController interface {
Generic() controller.GenericController
Informer() cache.SharedIndexInformer
Lister() EndpointsLister
AddHandler(ctx context.Context, name string, handler EndpointsHandlerFunc)
AddClusterScopedHandler(ctx context.Context, name, clusterName string, handler EndpointsHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type EndpointsGetter ¶
type EndpointsGetter interface {
Endpoints(namespace string) EndpointsInterface
}
type EndpointsHandlerFunc ¶
func NewEndpointsLifecycleAdapter ¶
func NewEndpointsLifecycleAdapter(name string, clusterScoped bool, client EndpointsInterface, l EndpointsLifecycle) EndpointsHandlerFunc
type EndpointsInterface ¶
type EndpointsInterface interface {
ObjectClient() *objectclient.ObjectClient
Create(*v1.Endpoints) (*v1.Endpoints, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.Endpoints, error)
Get(name string, opts metav1.GetOptions) (*v1.Endpoints, error)
Update(*v1.Endpoints) (*v1.Endpoints, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*EndpointsList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() EndpointsController
AddHandler(ctx context.Context, name string, sync EndpointsHandlerFunc)
AddLifecycle(ctx context.Context, name string, lifecycle EndpointsLifecycle)
AddClusterScopedHandler(ctx context.Context, name, clusterName string, sync EndpointsHandlerFunc)
AddClusterScopedLifecycle(ctx context.Context, name, clusterName string, lifecycle EndpointsLifecycle)
}
type EndpointsLifecycle ¶
type EndpointsList ¶
type EndpointsList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.Endpoints
}
func (*EndpointsList) DeepCopy ¶
func (in *EndpointsList) DeepCopy() *EndpointsList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EndpointsList.
func (*EndpointsList) DeepCopyInto ¶
func (in *EndpointsList) DeepCopyInto(out *EndpointsList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EndpointsList) DeepCopyObject ¶
func (in *EndpointsList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type EndpointsLister ¶
type Interface ¶
type Interface interface {
RESTClient() rest.Interface
controller.Starter
NodesGetter
ServiceAccountsGetter
EndpointsGetter
ServicesGetter
PodsGetter
ConfigMapsGetter
}
type NodeClient ¶
type NodeClient interface {
Create(*v1.Node) (*v1.Node, error)
Get(namespace, name string, opts metav1.GetOptions) (*v1.Node, error)
Update(*v1.Node) (*v1.Node, error)
Delete(namespace, name string, options *metav1.DeleteOptions) error
List(namespace string, opts metav1.ListOptions) (*NodeList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Cache() NodeClientCache
OnCreate(ctx context.Context, name string, sync NodeChangeHandlerFunc)
OnChange(ctx context.Context, name string, sync NodeChangeHandlerFunc)
OnRemove(ctx context.Context, name string, sync NodeChangeHandlerFunc)
Enqueue(namespace, name string)
Generic() controller.GenericController
ObjectClient() *objectclient.ObjectClient
Interface() NodeInterface
}
type NodeClientCache ¶
type NodeController ¶
type NodeController interface {
Generic() controller.GenericController
Informer() cache.SharedIndexInformer
Lister() NodeLister
AddHandler(ctx context.Context, name string, handler NodeHandlerFunc)
AddClusterScopedHandler(ctx context.Context, name, clusterName string, handler NodeHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type NodeHandlerFunc ¶
func NewNodeLifecycleAdapter ¶
func NewNodeLifecycleAdapter(name string, clusterScoped bool, client NodeInterface, l NodeLifecycle) NodeHandlerFunc
type NodeInterface ¶
type NodeInterface interface {
ObjectClient() *objectclient.ObjectClient
Create(*v1.Node) (*v1.Node, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.Node, error)
Get(name string, opts metav1.GetOptions) (*v1.Node, error)
Update(*v1.Node) (*v1.Node, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*NodeList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() NodeController
AddHandler(ctx context.Context, name string, sync NodeHandlerFunc)
AddLifecycle(ctx context.Context, name string, lifecycle NodeLifecycle)
AddClusterScopedHandler(ctx context.Context, name, clusterName string, sync NodeHandlerFunc)
AddClusterScopedLifecycle(ctx context.Context, name, clusterName string, lifecycle NodeLifecycle)
}
type NodeLifecycle ¶
type NodeList ¶
type NodeList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.Node
}
func (*NodeList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NodeList.
func (*NodeList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*NodeList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type NodeLister ¶
type NodesGetter ¶
type NodesGetter interface {
Nodes(namespace string) NodeInterface
}
type PodClient ¶
type PodClient interface {
Create(*v1.Pod) (*v1.Pod, error)
Get(namespace, name string, opts metav1.GetOptions) (*v1.Pod, error)
Update(*v1.Pod) (*v1.Pod, error)
Delete(namespace, name string, options *metav1.DeleteOptions) error
List(namespace string, opts metav1.ListOptions) (*PodList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Cache() PodClientCache
OnCreate(ctx context.Context, name string, sync PodChangeHandlerFunc)
OnChange(ctx context.Context, name string, sync PodChangeHandlerFunc)
OnRemove(ctx context.Context, name string, sync PodChangeHandlerFunc)
Enqueue(namespace, name string)
Generic() controller.GenericController
ObjectClient() *objectclient.ObjectClient
Interface() PodInterface
}
type PodClientCache ¶
type PodController ¶
type PodController interface {
Generic() controller.GenericController
Informer() cache.SharedIndexInformer
Lister() PodLister
AddHandler(ctx context.Context, name string, handler PodHandlerFunc)
AddClusterScopedHandler(ctx context.Context, name, clusterName string, handler PodHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type PodHandlerFunc ¶
func NewPodLifecycleAdapter ¶
func NewPodLifecycleAdapter(name string, clusterScoped bool, client PodInterface, l PodLifecycle) PodHandlerFunc
type PodInterface ¶
type PodInterface interface {
ObjectClient() *objectclient.ObjectClient
Create(*v1.Pod) (*v1.Pod, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.Pod, error)
Get(name string, opts metav1.GetOptions) (*v1.Pod, error)
Update(*v1.Pod) (*v1.Pod, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*PodList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() PodController
AddHandler(ctx context.Context, name string, sync PodHandlerFunc)
AddLifecycle(ctx context.Context, name string, lifecycle PodLifecycle)
AddClusterScopedHandler(ctx context.Context, name, clusterName string, sync PodHandlerFunc)
AddClusterScopedLifecycle(ctx context.Context, name, clusterName string, lifecycle PodLifecycle)
}
type PodLifecycle ¶
type PodList ¶
type PodList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.Pod
}
func (*PodList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PodList.
func (*PodList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PodList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PodsGetter ¶
type PodsGetter interface {
Pods(namespace string) PodInterface
}
type ServiceAccountChangeHandlerFunc ¶
type ServiceAccountChangeHandlerFunc func(obj *v1.ServiceAccount) (runtime.Object, error)
type ServiceAccountClient ¶
type ServiceAccountClient interface {
Create(*v1.ServiceAccount) (*v1.ServiceAccount, error)
Get(namespace, name string, opts metav1.GetOptions) (*v1.ServiceAccount, error)
Update(*v1.ServiceAccount) (*v1.ServiceAccount, error)
Delete(namespace, name string, options *metav1.DeleteOptions) error
List(namespace string, opts metav1.ListOptions) (*ServiceAccountList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Cache() ServiceAccountClientCache
OnCreate(ctx context.Context, name string, sync ServiceAccountChangeHandlerFunc)
OnChange(ctx context.Context, name string, sync ServiceAccountChangeHandlerFunc)
OnRemove(ctx context.Context, name string, sync ServiceAccountChangeHandlerFunc)
Enqueue(namespace, name string)
Generic() controller.GenericController
ObjectClient() *objectclient.ObjectClient
Interface() ServiceAccountInterface
}
type ServiceAccountClientCache ¶
type ServiceAccountClientCache interface {
Get(namespace, name string) (*v1.ServiceAccount, error)
List(namespace string, selector labels.Selector) ([]*v1.ServiceAccount, error)
Index(name string, indexer ServiceAccountIndexer)
GetIndexed(name, key string) ([]*v1.ServiceAccount, error)
}
type ServiceAccountController ¶
type ServiceAccountController interface {
Generic() controller.GenericController
Informer() cache.SharedIndexInformer
Lister() ServiceAccountLister
AddHandler(ctx context.Context, name string, handler ServiceAccountHandlerFunc)
AddClusterScopedHandler(ctx context.Context, name, clusterName string, handler ServiceAccountHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type ServiceAccountHandlerFunc ¶
func NewServiceAccountLifecycleAdapter ¶
func NewServiceAccountLifecycleAdapter(name string, clusterScoped bool, client ServiceAccountInterface, l ServiceAccountLifecycle) ServiceAccountHandlerFunc
type ServiceAccountIndexer ¶
type ServiceAccountIndexer func(obj *v1.ServiceAccount) ([]string, error)
type ServiceAccountInterface ¶
type ServiceAccountInterface interface {
ObjectClient() *objectclient.ObjectClient
Create(*v1.ServiceAccount) (*v1.ServiceAccount, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.ServiceAccount, error)
Get(name string, opts metav1.GetOptions) (*v1.ServiceAccount, error)
Update(*v1.ServiceAccount) (*v1.ServiceAccount, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*ServiceAccountList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() ServiceAccountController
AddHandler(ctx context.Context, name string, sync ServiceAccountHandlerFunc)
AddLifecycle(ctx context.Context, name string, lifecycle ServiceAccountLifecycle)
AddClusterScopedHandler(ctx context.Context, name, clusterName string, sync ServiceAccountHandlerFunc)
AddClusterScopedLifecycle(ctx context.Context, name, clusterName string, lifecycle ServiceAccountLifecycle)
}
type ServiceAccountLifecycle ¶
type ServiceAccountLifecycle interface {
Create(obj *v1.ServiceAccount) (runtime.Object, error)
Remove(obj *v1.ServiceAccount) (runtime.Object, error)
Updated(obj *v1.ServiceAccount) (runtime.Object, error)
}
type ServiceAccountList ¶
type ServiceAccountList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.ServiceAccount
}
func (*ServiceAccountList) DeepCopy ¶
func (in *ServiceAccountList) DeepCopy() *ServiceAccountList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServiceAccountList.
func (*ServiceAccountList) DeepCopyInto ¶
func (in *ServiceAccountList) DeepCopyInto(out *ServiceAccountList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ServiceAccountList) DeepCopyObject ¶
func (in *ServiceAccountList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ServiceAccountLister ¶
type ServiceAccountLister interface {
List(namespace string, selector labels.Selector) (ret []*v1.ServiceAccount, err error)
Get(namespace, name string) (*v1.ServiceAccount, error)
}
type ServiceAccountsGetter ¶
type ServiceAccountsGetter interface {
ServiceAccounts(namespace string) ServiceAccountInterface
}
type ServiceClient ¶
type ServiceClient interface {
Create(*v1.Service) (*v1.Service, error)
Get(namespace, name string, opts metav1.GetOptions) (*v1.Service, error)
Update(*v1.Service) (*v1.Service, error)
Delete(namespace, name string, options *metav1.DeleteOptions) error
List(namespace string, opts metav1.ListOptions) (*ServiceList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Cache() ServiceClientCache
OnCreate(ctx context.Context, name string, sync ServiceChangeHandlerFunc)
OnChange(ctx context.Context, name string, sync ServiceChangeHandlerFunc)
OnRemove(ctx context.Context, name string, sync ServiceChangeHandlerFunc)
Enqueue(namespace, name string)
Generic() controller.GenericController
ObjectClient() *objectclient.ObjectClient
Interface() ServiceInterface
}
type ServiceClientCache ¶
type ServiceController ¶
type ServiceController interface {
Generic() controller.GenericController
Informer() cache.SharedIndexInformer
Lister() ServiceLister
AddHandler(ctx context.Context, name string, handler ServiceHandlerFunc)
AddClusterScopedHandler(ctx context.Context, name, clusterName string, handler ServiceHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type ServiceHandlerFunc ¶
func NewServiceLifecycleAdapter ¶
func NewServiceLifecycleAdapter(name string, clusterScoped bool, client ServiceInterface, l ServiceLifecycle) ServiceHandlerFunc
type ServiceInterface ¶
type ServiceInterface interface {
ObjectClient() *objectclient.ObjectClient
Create(*v1.Service) (*v1.Service, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.Service, error)
Get(name string, opts metav1.GetOptions) (*v1.Service, error)
Update(*v1.Service) (*v1.Service, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*ServiceList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() ServiceController
AddHandler(ctx context.Context, name string, sync ServiceHandlerFunc)
AddLifecycle(ctx context.Context, name string, lifecycle ServiceLifecycle)
AddClusterScopedHandler(ctx context.Context, name, clusterName string, sync ServiceHandlerFunc)
AddClusterScopedLifecycle(ctx context.Context, name, clusterName string, lifecycle ServiceLifecycle)
}
type ServiceLifecycle ¶
type ServiceList ¶
type ServiceList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.Service
}
func (*ServiceList) DeepCopy ¶
func (in *ServiceList) DeepCopy() *ServiceList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServiceList.
func (*ServiceList) DeepCopyInto ¶
func (in *ServiceList) DeepCopyInto(out *ServiceList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ServiceList) DeepCopyObject ¶
func (in *ServiceList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ServiceLister ¶
type ServicesGetter ¶
type ServicesGetter interface {
Services(namespace string) ServiceInterface
}
Source Files
¶
- zz_generated_config_map_controller.go
- zz_generated_config_map_lifecycle_adapter.go
- zz_generated_deepcopy.go
- zz_generated_endpoints_controller.go
- zz_generated_endpoints_lifecycle_adapter.go
- zz_generated_k8s_client.go
- zz_generated_node_controller.go
- zz_generated_node_lifecycle_adapter.go
- zz_generated_pod_controller.go
- zz_generated_pod_lifecycle_adapter.go
- zz_generated_scheme.go
- zz_generated_service_account_controller.go
- zz_generated_service_account_lifecycle_adapter.go
- zz_generated_service_controller.go
- zz_generated_service_lifecycle_adapter.go